/*
 * *********************************************************************************************************************************************
 * "THE BEER-WARE LICENSE" (Revision 42):
 * Mario Hellmich <mario.hellmich@web.de> wrote this file. As long as you retain this
 * notice you can do whatever you want with this stuff. If we meet some day,
 * and you think this stuff is worth it, you can buy me a beer in return.
 * Mario Hellmich
 * *********************************************************************************************************************************************
 * File: globals.c
 *
 * Version 1.0
 *
 * Created: 21.02.2021
 * Author:  Mario Hellmich <mario.hellmich@web.de>
 * Project: CW Signal Generator Mk-II
 *
 * Some global variable declarations for basic functions (further globals are defined in other header files) and #defines in globals.h.
 * Global const variables are defined here.
 *
 */


#include <avr/io.h>

#include "globals.h"




/*
************************************************************************************************************************************************
Global variable definitions:
*/

volatile uint64_t frequency;																// Synthesizer output frequency in Hz
volatile int16_t  output_level;																// Output level in multiples of 0.1 dBm
volatile uint8_t  ref_mult;																	// Reference multiplier; ref_mult = 100 MHz / (current reference frequency)
volatile struct status_s status;															// Bitfield containing system status and error information

const uint64_t f_int_ref = 10000000;														// Internal reference frequency, 10 MHz
const uint64_t mpll_fref = 100000000;														// Mail PLL reference frequency as supplied to chip
const uint64_t f_pfd     = 100000000;														// PFD frequency of mail PLL, in this project 100 MHz

const uint8_t version_major = 1;															// Firmware version number integer
const uint8_t version_minor = 0;															// Firmware version number decimal