/*
 * *********************************************************************************************************************************************
 * "THE BEER-WARE LICENSE" (Revision 42):
 * Mario Hellmich <mario.hellmich@web.de> wrote this file. As long as you retain this
 * notice you can do whatever you want with this stuff. If we meet some day,
 * and you think this stuff is worth it, you can buy me a beer in return.
 * Mario Hellmich
 * *********************************************************************************************************************************************
 * File: globals.h
 *
 * Version 1.0
 *
 * Created: 21.02.2021
 * Author:  Mario Hellmich <mario.hellmich@web.de>
 * Project: CW Signal Generator Mk-II
 *
 * Some global variable declarations for basic functions (further globals are defined in other header files) and #defines.
 * Global const variables are defined in globals.c
 *
 */


#ifndef GLOBALS_H_
#define GLOBALS_H_


// Global variables and structs
extern volatile uint64_t frequency;															// Synthesizer output frequency in Hz
extern volatile int16_t output_level;														// Output level in multiples of 0.1 dBm
extern volatile uint8_t ref_mult;															// Reference multiplier; ref_mult = 100 MHz / (reference frequency)

// Global constants
extern const uint64_t f_int_ref;															// Internal reference frequency, 10 MHz
extern const uint64_t f_pfd;																// PFD frequency of mail PLL, in this project 100 MHz
extern const uint64_t mpll_fref;															// Mail PLL reference frequency as supplied to chip
extern const uint8_t version_major;															// Firmware version number integer
extern const uint8_t version_minor;															// Firmware version number decimal


struct status_s {																			// System status bitfield
	uint8_t extref : 1;																		// Reference mode, extref = 0: internal, extref = 1: external
	uint8_t err : 1;																		// Hardware error detected
	uint8_t refpll_unlock : 1;																// Reference PLL unlocked
	uint8_t mpll_unlock : 1;																// Main PLL unlocked
	uint8_t alc_unlvld : 1;																	// Output unleveled, ALC range exhausted
	uint8_t arg_range : 1;																	// Argument of last command out of range, is cleared when the error status is read
};

extern volatile struct status_s status;														// Declare system status bitfield


// Constants
#define MAX_FREQ			4200000000														// Maximum output frequency in Hz
#define MIN_FREQ			20000000														// Minimum output frequency in Hz
#define MAX_LEV				100																// Maximum output level in multiples of 0.1 dBm = 10 dBm
#define MIN_LEV				-450															// Minimum output level in multiples of 0.1 dBm = -45 dBm
#define MAX_REFMULT			255																// Maximum reference multiplier value (corresponding to f_ref = 392.156862 kHz)
#define MIN_REFMULT			10																// Minimum reference multiplier value (corresponding to f_ref = 10 MHz)
#define MAX_LCORR_VAL		5000															// Maximum output level correction value = 50 dB
#define MIN_LCORR_VAL		-5000															// Minimum output level correction value = -50 dB
#define MAX_FCORR_VAL		10000															// Maximum reference frequency correction value = 1000 Hz
#define MIN_FCORR_VAL		-10000															// Minimum reference frequency correction value = -1000 Hz
#define MAX_SLCORR_VAL		300000															// Maximum detector slope correction value = 300 mV/dB
#define MIN_SLCORR_VAL		-30000															// Minimum detector slope correction value = -300 mV/dB
#define NMEM				9																// Maximum instrument setup memory identification number, (i.e. memories are from from 0 to NMEM)


// Boolean
#define SUCCESS				1
#define FAIL				0
#define TRUE				1
#define FALSE				0
#define ON					1
#define OFF					0


#endif /* GLOBALS_H_ */